@@ -1,7 +1,8 @@
 from GLXShell.plugins.builtins import GLXShPluginBuiltins
+from GLXShell.plugins.builtins import PLUGIN_VERSION
 
 
-class GLXShellPropertyPlugins(object):
+class GLXShPropertyPlugins(object):
     def __init__(self):
         self.__plugins = None
         self.plugins = None
@@ -28,7 +29,13 @@ class GLXShellPropertyPlugins(object):
         :raise TypeError: when property value is not a list or None
         """
         if value is None:
-            value = [{"name": "builtins", "object": GLXShPluginBuiltins()}]
+            value = [
+                {
+                    "name": "builtins",
+                    "version": PLUGIN_VERSION,
+                    "object": GLXShPluginBuiltins(),
+                }
+            ]
         if type(value) != list:
             raise TypeError("'commands' property value must be a list or None")
         if self.plugins != value:
