@@ -6,9 +6,9 @@ import sys
 # https://www.maizure.org/projects/decoded-gnu-coreutils/
 # https://www.maizure.org/projects/decoded-gnu-coreutils/cat.html
 
-from GLXShell.plugins.builtins import __version__
-from GLXShell.plugins.builtins import __appname__
-from GLXShell.plugins.builtins import __licence__
+from GLXShell.plugins.builtins import PLUGIN_VERSION
+from GLXShell.plugins.builtins import PLUGIN_DESCRIPTION
+from GLXShell.plugins.builtins import PLUGIN_WARRANTY
 
 cat_parser = argparse.ArgumentParser()
 cat_parser.add_argument(
@@ -97,9 +97,9 @@ class GLXCat(cmd2.CommandSet):
     def cat_print_version():
         cmd2.Cmd().poutput(
             "cat ({name}) v{version}\n{licence}".format(
-                name=__appname__,
-                version=__version__,
-                licence=__licence__,
+                name=PLUGIN_DESCRIPTION,
+                version=PLUGIN_VERSION,
+                licence=PLUGIN_WARRANTY,
             )
         )
 
