@@ -2,9 +2,9 @@ import cmd2
 import sys
 import platform
 
-from GLXShell.plugins.builtins import __version__
-from GLXShell.plugins.builtins import __appname__
-from GLXShell.plugins.builtins import __licence__
+from GLXShell.plugins.builtins import PLUGIN_VERSION
+from GLXShell.plugins.builtins import PLUGIN_DESCRIPTION
+from GLXShell.plugins.builtins import PLUGIN_WARRANTY
 
 uname_parser = cmd2.Cmd2ArgumentParser()
 uname_parser.add_argument(
@@ -58,9 +58,9 @@ class GLXUname(cmd2.CommandSet):
     def uname_print_version(self):
         cmd2.Cmd().poutput(
             "uname ({name}) v{version}\n{licence}".format(
-                name=__appname__,
-                version=__version__,
-                licence=__licence__,
+                name=PLUGIN_DESCRIPTION,
+                version=PLUGIN_VERSION,
+                licence=PLUGIN_WARRANTY,
             )
         )
         self.stdout.flush()
